<?php
/**
*
* @package phpBB Extension - Stoker Portal
* @copyright (c) 2015 Stoker www.phpbb3bbcodes.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\portal\acp;

/**
* @ignore
*/


/**
* @package acp
*/
class acp_portal_module
{
	public $u_action;

	public function main()
	{
		global $request, $template;
		global $config, $phpbb_root_path, $phpEx, $phpbb_container;

		/** @var \phpbb\language\language $lang */
		$language = $phpbb_container->get('language');

		$language->add_lang(array('acp/board', 'posting'));

		$this->tpl_name = 'acp_portal';
		$this->page_title = 'PORTAL_SETTINGS';

		$form_name = 'portal_setting';
		add_form_key($form_name);
		$error = '';

		$config_text = $phpbb_container->get('config_text');
		$portal_data	= $config_text->get_array([
			'portal_info',
			'portal_info_uid',
			'portal_info_bitfield',
			'portal_info_flags',
		]);

		$portal_info = $portal_data['portal_info'];
		$portal_info_uid = $portal_data['portal_info_uid'];
		$portal_info_bitfield= $portal_data['portal_info_bitfield'];
		$portal_info_flags	= $portal_data['portal_info_flags'];

		if ($request->is_set_post('submit') || $request->is_set_post('preview'))
		{
			if (!check_form_key($form_name))
			{
				$error = $language->lang('FORM_INVALID');
			}
			
			$portal_info = $request->variable('portal_info', '', true);
			generate_text_for_storage(
				$portal_info,
				$portal_info_uid,
				$portal_info_bitfield,
				$portal_info_flags,
				!$request->variable('disable_bbcode', false),
				!$request->variable('disable_magic_url', false),
				!$request->variable('disable_smilies', false)
			);
			if (empty($error) && $request->is_set_post('submit'))
			{
				$config->set('acp_portal_meta_noindex', $request->variable('acp_portal_meta_noindex', false));
				$config->set('acp_portal_enable', $request->variable('acp_portal_enable', false));

				$config_text->set_array([
					'portal_info'			=> $portal_info,
					'portal_info_uid'		=> $portal_info_uid,
					'portal_info_bitfield'	=> $portal_info_bitfield,
					'portal_info_flags'		=> $portal_info_flags,
				]);
				trigger_error($language->lang('PORTAL_UPDATED') . adm_back_link($this->u_action));
			}
		}

		$portal_info_preview = '';
		if ($request->is_set_post('preview') || $portal_info)
		{
			$portal_info_preview = generate_text_for_display($portal_info, $portal_info_uid, $portal_info_bitfield, $portal_info_flags);
		}
		
		$portal_edit = generate_text_for_edit($portal_info, $portal_info_uid, $portal_info_flags);
		
		$template->assign_vars([
			'ACP_PORTAL_INFO'				=> $portal_edit['text'],
			'ACP_PORTAL_INFO_PREVIEW'		=> $portal_info_preview,

			'PORTAL_ENABLE'					=> $config['acp_portal_enable'],
			'PORTAL_VERSION'				=> $config['portal_version'],

			'ERRORS'						=> $error,
			'META_NOINDEX'					=> $config['acp_portal_meta_noindex'],

			'S_BBCODE_DISABLE_CHECKED'		=> !$portal_edit['allow_bbcode'],
			'S_MAGIC_URL_DISABLE_CHECKED'	=> !$portal_edit['allow_urls'],
			'S_SMILIES_DISABLE_CHECKED'		=> !$portal_edit['allow_smilies'],

			'BBCODE_STATUS'					=> $language->lang('BBCODE_IS_ON', '<a href="' . $phpbb_container->get('controller.helper')->route('phpbb_help_bbcode_controller') . '">', '</a>'),

			'FLASH_STATUS'					=> $language->lang('FLASH_IS_ON'),
			'IMG_STATUS'					=> $language->lang('IMAGES_ARE_ON'),
			'SMILIES_STATUS'				=> $language->lang('SMILIES_ARE_ON'),
			'URL_STATUS'					=> $language->lang('URL_IS_ON'),

			'U_ACTION'						=> $this->u_action,
			'U_MORE_SMILIES'    			=> append_sid("{$phpbb_root_path}posting.$phpEx", 'mode=smilies'),
			
			'S_BBCODE_ALLOWED'				=> true,
			'S_BBCODE_FLASH'				=> true,
			'S_BBCODE_IMG'					=> true,
			'S_LINKS_ALLOWED'				=> true,
			'S_SMILIES_ALLOWED'				=> true,
		]);
		
		if ($config['allow_bbcode'] == true)
		{
			if (!function_exists('display_custom_bbcodes'))
			{
				include($phpbb_root_path . 'includes/functions_display.' . $phpEx);
			}
			display_custom_bbcodes();
		}
		
		if ($config['allow_smilies'] == true)
		{	
			if (!function_exists('generate_smilies'))
			{
				include_once $phpbb_root_path . 'includes/functions_posting.' . $phpEx;
			}
			generate_smilies('inline', 0);	
		}	
	}
}
