<?php
/**
*
* @package phpBB Extension - Stoker Portal
* @copyright (c) 2015 Stoker www.phpbb3bbcodes.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\portal\controller;

/**
* @ignore
*/

class main
{
	/* @var \phpbb\config\config */
	protected $config;

	/* @var \phpbb\config\db_text */
	protected $config_text;

	/* @var \phpbb\controller\helper */
	protected $helper;

	/* @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\language\language */
	protected $language;
	
	/* @var \phpbb\user */
	protected $user;

	/**
	* Constructor
	*
	* @param \phpbb\config\config		$config
	* @param \phpbb\config\db_text		$config_text
	* @param \phpbb\controller\helper	$helper
	* @param \phpbb\template\template	$template
	* @param \phpbb\language\language	$language
	*/

	public function __construct(
		\phpbb\config\config $config,
		\phpbb\config\db_text $config_text,
		\phpbb\controller\helper $helper,
		\phpbb\template\template $template,
		\phpbb\language\language $language,
		\phpbb\user $user)
	{
		$this->config 		= $config;
		$this->config_text 	= $config_text;
		$this->helper 		= $helper;
		$this->template 	= $template;
		$this->language 	= $language;
		$this->user 		= $user;
		
		if (empty($this->config['acp_portal_enable']))
		{
			throw new \phpbb\exception\http_exception(404, 'PAGE_NOT_FOUND');
		}
	}

	/**
	* Controller for route app.php/portal.php and /portal
	*
	* @return Symfony\Component\HttpFoundation\Response A Symfony Response object
	*/
	public function base()
	{
		$date = $this->user->format_date(time(), 'H');

		if ($this->user->data['is_registered'])
		{
			$u_user_name = get_username_string('full', $this->user->data['user_id'], $this->user->data['username'], $this->user->data['user_colour']);
		}
		else
		{
			$u_user_name = $this->user->lang['WELCOME_GUEST'];
		}    

		switch (true)
		{
				case ($date < 1):
					// if the hour is 01 - 23
					$s_welcome = sprintf($this->user->lang['GOOD_NIGHT'], $u_user_name);;
				break;
				
				case ($date < 4):
					// if the hour is 01 - 04
					$s_welcome = sprintf($this->user->lang['UP_LATE'], $u_user_name);
				break;
				
				case ($date < 7):
					// if the hour is 04 - 07 
					$s_welcome = sprintf($this->user->lang['UP_EARLY'], $u_user_name);
				break;
				
				case ($date < 10):
					// if the hour is 07 - 10 am
					$s_welcome = sprintf($this->user->lang['GOOD_MORNING'], $u_user_name);
				break;
				
				case ($date < 14):
					// if the hour is 10 - 14
					$s_welcome = sprintf($this->user->lang['GOOD_DAY'], $u_user_name);
				break;
				
				case ($date < 18):
					// if the hour is 14 - 18
					$s_welcome = sprintf($this->user->lang['GOOD_AFTERNOON'], $u_user_name);
				break;
				
				case ($date < 24):
					// if the hour is 18 - 24
					$s_welcome = sprintf($this->user->lang['GOOD_EVENING'], $u_user_name);;
				break;
		}

		// how long a member for
		$member_for = '';
		if ($this->user->data['is_registered'] && !$this->user->data['is_bot'])
		{
			$member_length = (int) time() - (int) $this->user->data['user_regdate'];
			$years = $months = $days = 0;
			$member_for = '';
			if ($member_length)
			{    
				if ($member_length >= 31536000)
				{
					$years = (int) ($member_length / (365.25*60*60*24));
					$member_length = (int) $member_length - ( (int) $years * (365.25*60*60*24));
					$member_for .= $years > 1 ? ((int) $years . '&nbsp;' . $this->user->lang['WELCOME_YEARS']) : ((int) $years . '&nbsp;' . $this->user->lang['WELCOME_YEAR']);
				}
				$months = (int) ($member_length / 2628000);
				if ($months)
				{
					$member_length = (int) $member_length - ((int) $months * 2628000);
					$months = (int) $months > 1 ? ', ' . ((int) $months . '&nbsp;' . $this->user->lang['WELCOME_MONTHS']) : ', ' .  ((int) $months . '&nbsp;' . $this->user->lang['WELCOME_MONTH']);
					$member_for .= $months;
				}
				$days = (int) ($member_length / 86400);
				if ($days)
				{
					$member_length = (int) $member_length - ((int) $days * 86400);
					$days = (int) $days > 1 ? ', ' . ((int) $days . '&nbsp;' . $this->user->lang['WELCOME_DAYS']) : ', ' . ($days . '&nbsp;' . $this->user->lang['WELCOME_DAY']);
					$member_for .= $days;
				}        
			}
		}

		$portal_data = $this->config_text->get_array(array(
				'portal_info',
				'portal_info_uid',
				'portal_info_bitfield',
				'portal_info_flags',
		));

		$portal_text = generate_text_for_display(
			$portal_data['portal_info'],
			$portal_data['portal_info_uid'],
			$portal_data['portal_info_bitfield'],
			$portal_data['portal_info_flags']
		);

		$this->template->assign_vars(array(
			'S_WELCOME'		=> $s_welcome,
			'S_JOINED_DATE'	=> $this->user->format_date($this->user->data['user_regdate']),
			'MEMBER_FOR'	=> (!empty($member_for)) ? $this->user->lang['MEMBER_FOR'] . '&nbsp;' . $member_for : '',
			'PORTAL_OUTPUT'	=> $portal_text,
			'META'			=> ($this->config['acp_portal_meta_noindex']) ? '<meta name="robots" content="noindex" />' : '',
			'PORTAL_ENABLE'	=> $this->config['acp_portal_enable'],
		));

		return $this->helper->render('portal.html', $this->language->lang('PORTAL'));
	}

	public function redirect()
	{
		redirect($this->helper->route('stoker_portal'));
	}
}
